#uses "moonAdditionalFunctions.ctl"
#uses "fwConfigurationDBSystemInformation/fwConfigurationDBSystemInformation.ctl"

const int FSYTEMOVERVIEWWALARMSMASKING_RETRIES = 10;
const string FWSYSETMOVERVIEWALARMSMASKING_TIME_FORMAT = "%Y.%m.%d %H:%M:%S";


---
int fwSystemOverviewAlarmsMasking_setAlarmMaskHideLocally(string action, string dpe)
{
  //find the system name
  string sys = fwSysOverviewNotifications_dpSubStr(dpe, DPSUB_SYS);
  strreplace(sys, ":", "");
  //find siDp:
  dyn_string dps = dpNames("moon_300:icemonSystemIntegrity_"+sys+"_*.", "IcemonSystemIntegrity");
  if(dynlen(dps) != 1)
  {
    DebugN("Could not resolve SI DP for system: " + sys + ", dpe used:" + dpe);
    return -1;
  }
  string siDp = dps[1];
  
  //get current values of mask and hide 
  dyn_string oldAlarmsDpes;
  dyn_bool oldMaskedLocally, oldHiddenLocally;
      
  dpGet(siDp + "applicationAlarmsList.dpes", oldAlarmsDpes,
        siDp + "applicationAlarmsList.locallyMasked", oldMaskedLocally,
        siDp + "applicationAlarmsList.locallyHidden", oldHiddenLocally);
     
  //find the dpe among the list of dpes:
  int pos = dynContains(oldAlarmsDpes, dpe);
    
  if(pos > 0 && dynlen(oldMaskedLocally) >= pos && dynlen(oldHiddenLocally) >= pos)
  {
    if(action == "MASK")
    {
      oldMaskedLocally[pos] = true;
    }
    else if(action == "UNMASK")
    {
      oldMaskedLocally[pos] = false;
    }
    else if(action == "SET NO SBS")
    {
      oldHiddenLocally[pos] = true;
    }
    else if(action == "SET SBS")
    {
      oldHiddenLocally[pos] = false;
    }

    return   dpSet(siDp + "applicationAlarmsList.locallyMasked", oldMaskedLocally,
                   siDp + "applicationAlarmsList.locallyHidden", oldHiddenLocally);
    
  }
    
  DebugN("Could not find dpe: " + dpe + " among the list of SI alarms: " + oldAlarmsDpes);
  return -1; 
}


---

void fwSystemOverviewAlarmsMasking_RemoveAlarmFromDp(string fwMaskedAlarmDp, string alarmDp)
{
  if (!_fwSystemOverviewAlarmsMasking_useDp(fwMaskedAlarmDp))
    return;
  
  dyn_string alarmsDpes, comments;
  dpGet(fwMaskedAlarmDp + ".dpeList", alarmsDpes,
        fwMaskedAlarmDp + ".comment", comments);

  int position = dynContains(alarmsDpes, alarmDp);
  if (position > 0)
  {
    dynRemove(alarmsDpes, position);
    dynRemove(comments, position);    
    if (dynlen(alarmsDpes) > 0)
    {
      dpSetWait(fwMaskedAlarmDp + ".dpeList", alarmsDpes,
              fwMaskedAlarmDp + ".comment", comments);
    }
    else
    {
      dpSetWait(fwMaskedAlarmDp + ".dpeList", alarmsDpes,
              fwMaskedAlarmDp + ".comment", comments,
              fwMaskedAlarmDp + ".active", false);
    }
  }
  else
  {
    dyn_string ex;
    fwException_raise(ex, "ERROR", "dpeList :" + alarmsDpes + " does not contain dp with name: " +alarmDp, "fwSystemOverviewAlarmsMasking_RemoveAlarmFromDp"); 
  } 
  _fwSystemOverviewAlarmsMasking_releaseDp(fwMaskedAlarmDp);
}

void fwSystemOverviewAlarmsMasking_logEvent(string loggerDpName, string eventText, time eventTime, string user, dyn_string affectedDpes)
{
  int retries = 0;
  
  if (!_fwSystemOverviewAlarmsMasking_useDp(loggerDpName))
    return;
  
  
  string affectedDpesStr;
  fwGeneral_dynStringToString(affectedDpes, affectedDpesStr, ",");
  
  dpSetWait(loggerDpName + ".event", eventText,
        loggerDpName + ".eventTime", eventTime,
        loggerDpName + ".user", user,
        loggerDpName + ".affectedDpes", affectedDpesStr);
  _fwSystemOverviewAlarmsMasking_releaseDp(loggerDpName);
  fwConfigurationDBSystemInformation_logAction(eventText, eventTime, user);
}

bool _fwSystemOverviewAlarmsMasking_isInUse(string dpName)
{
  bool isInUse;
  dpGet(dpName + ".isInUse", isInUse);
  return isInUse;
}

bool _fwSystemOverviewAlarmsMasking_useDp(string dpName)
{
  while (_fwSystemOverviewAlarmsMasking_isInUse(dpName))
  {
    int retries;
    if (retries <= FWSYSTEMOVERVIEWALARMSMASKING_RETRIES)
    {
      retries++;
      delay(0, 10);
    }
    else
    {
      dyn_string ex;
      fwException_raise(ex, "ERROR", "DP: " + dpName +" in use. Number of retries: " + FWSYSTEMOVERVIEWALARMSMASKING_RETRIES, "fwSystemOverviewAlarmsMasking_logEvent");
      return false;
    }
  }
  dpSetWait(dpName + ".isInUse", true);
  return true;
}

void _fwSystemOverviewAlarmsMasking_releaseDp(string dpName)
{
  dpSetWait(dpName + ".isInUse", false);
}



void fwSystemOverviewAlarmsMasking_maskAlarms(string action, dyn_string alarms, string comment, string date, bool isEdit = false, dyn_string  alarmsDpes = makeDynString(), string function = "", dyn_string functionArguments = makeDynString())
{
  int updateResult;
  string dpName;
  dyn_string tmp;

  //deactivate alarms
  dyn_string ex;
  if (isEdit)
  {

    //editing -> delete the alarms from the old dps. New dps for them will be created later in this method
    for (int i=1; i<= dynlen(dpesEdit); i++)
    {
      fwSystemOverviewAlarmsMasking_RemoveAlarmFromDp(dpesEdit[i], alarmsDpes[i]);
    }  

  }
  else
  {
    dyn_string localAlarms;
    //deactivate the alarms from the local system and set flag for the alarms of the remote systems
    for(int i=1; i<= dynlen(alarms); i++)
    {
      string systemName = fwSysOverviewNotifications_dpSubStr(alarms[i], DPSUB_SYS);
      if (systemName ==getSystemName())
      {
        dynAppend(localAlarms, alarms[i]);
      }
      else
      {
        fwSystemOverviewAlarmsMasking_setAlarmMaskHideLocally(action, alarms[i]);
      }
    }

    if(action == "MASK")
    {
      fwAlertConfig_deactivateMultiple(localAlarms, ex);    
    }
    else if(action == "UNMASK")
    {
      fwAlertConfig_activateMultiple(localAlarms, ex);    
    }
  }
  
  //update/create FwMaskedAlarms dp
  if (date != "")
  {
    dpName =  _fwSystemOverviewAlarmsMasking_getAvailableDp();
    updateResult = dpSetWait(dpName + ".dpeList", alarms,
          dpName + ".comment", _fwSystemOverviewAlarmsMasking_multiplyComment(comment, dynlen(alarms)),
          dpName + ".expirationDate", date,
          dpName + ".active", true,
          dpName + ".function.name", function,
          dpName + ".function.arguments", functionArguments);
   
  }
  else 
  {
    //the dp with inex 0 will contain all alarms without expiration date
    dpName = "fwMaskedAlarms_0";
    dyn_string comments = makeDynString();
    dyn_string alarmDpes = makeDynString();
    if (dpExists(dpName))
    {
      _fwSystemOverviewAlarmsMasking_useDp(dpName);
      dpGet(dpName + ".comment", comments,
            dpName + ".dpeList", alarmDpes);
    }
    else 
    {
      dpCreate(dpName, "FwMaskedAlarms");
      _fwSystemOverviewAlarmsMasking_useDp(dpName);
    }
    tmp = alarms;
    dynAppend(alarmDpes, tmp);
    dynAppend(comments, _fwSystemOverviewAlarmsMasking_multiplyComment(comment, dynlen(alarms)));

    updateResult = dpSetWait(dpName + ".dpeList", alarmDpes,
                             dpName + ".active", true,
                             dpName + ".comment", comments);
    _fwSystemOverviewAlarmsMasking_releaseDp(dpName);
    
  }

  //log the events
  if (updateResult != 0)
  {
    DebugN(getLastError());
     dyn_string ex;     
     fwException_raise(ex, "ERROR", "Failed to create set values for dp " + dpName+ ": " + getLastError(), "dpSetWait");
  }
  else
  {
    string user;
    fwAccessControl_getUserName(user);
    if (isEdit)
      fwSystemOverviewAlarmsMasking_logEvent("moonAlarmsMaskingLogger", "Masked alarm edited. New expiration date: " + validTo.text +" and comment: " + txComment.text, getCurrentTime(), user, alarms); 
    else
      fwSystemOverviewAlarmsMasking_logEvent("moonAlarmsMaskingLogger", "Alarms masked with expiration date: " + validTo.text +" and comment: " + txComment.text, getCurrentTime(), user, alarms); 

  }
}

string _fwSystemOverviewAlarmsMasking_getAvailableDp()
{
  string dpName;
  dyn_string fwMaskedAlarmsDps = dpNames("*.active", "FwMaskedAlarms");

  dyn_bool maskingActive;
  dpGet(fwMaskedAlarmsDps, maskingActive);
  for (int i=1; i<= dynlen(fwMaskedAlarmsDps); i++)
  {
    if (!maskingActive[i])
    {
      dpName = dpSubStr(fwMaskedAlarmsDps[i], DPSUB_DP);
      break;
    }
  }
    
  // all dps are used
  if (dpName == "")
  {
     int idx = 0;
     while(dpExists("fwMaskedAlarms_" + idx))
     {
       idx++;
     }
     dpCreate("fwMaskedAlarms_" + idx, "FwMaskedAlarms");
     dpName = "fwMaskedAlarms_" + idx;
   }
   
  return dpName;
}

dyn_string _fwSystemOverviewAlarmsMasking_multiplyComment(string text, int count)
{
  dyn_string comments;
  for(int i=1; i<=count; i++)
    dynAppend(comments, text);
  
  return comments;
}
void fwSystemOverviewAlarmsMasking_queryApplicationAlarmDpes(string domain, string lunit, dyn_string& alarms, dyn_bool& alarmsMasked, dyn_bool& alarmsHidden, dyn_bool& alarmsPresent, string dpPattern = "", string aliasPattern = "", string descriptionPattern = "")
{
  dynClear(alarms);
  dynClear(alarmsMasked);
  dynClear(alarmsHidden);
  dynClear(alarmsPresent);
  
  dyn_string dps = fwUi_getIncludedTreeDevices(domain, lunit);
  dynUnique(dps);  
  
  dyn_string types = fwSysOverview_getApplicationsAlarmsTypes();

  for(int j = 1; j <= dynlen(types); j++)
  {
    for(int k = 1; k <= dynlen(dps); k++)
    {
      string dp = "";
      if(!dpExists(dps[k]))
      {
        dp = dpAliasToName(dps[k]);                
        dp = dpSubStr(dp, DPSUB_DP);
      }
      else
        dp = dps[k];
      
      dyn_string dpes = dpNames(dp + "*.**", types[j]);
      int n = dynlen(dpes);
      
      for(int i = 1; i <= n; i++)
      {
        if(dpElementType(dpes[i]) == DPEL_STRUCT)
        {
          continue;
        }
        
        //Filters
        if (dpPattern != "" && !patternMatch("*" + dpPattern + "*", dpes[i]))
        {
          continue;
        }

        if (aliasPattern != "" && !patternMatch("*" + aliasPattern + "*", dpGetAlias(dpes[i])))
        {
          continue;
        }

        if (descriptionPattern != "" && !patternMatch("*" + descriptionPattern + "*", dpGetDescription(dpes[i])))
        {
          continue;
        }
      
        int configured = 0, active = 0, present = 0;
        dpGet(dpes[i] + ":_alert_hdl.._type", configured, 
              dpes[i] + ":_alert_hdl.._active", active,
              dpes[i] + ":_alert_hdl.._act_state", present);
        
        if(configured )//&& active == 0)
        {
          dynAppend(alarms, dpes[i]);
          dynAppend(alarmsMasked, !active);          
          dynAppend(alarmsHidden, false); //hiding alarms is only possible for SI alarms from the remote systems.
          dynAppend(alarmsPresent, present);       
        }
      }
    }
  }
  
  fwSystemOverviewAlarmsMasking_addRemoteSystemIntegrityAlarms(domain, lunit, alarms, alarmsMasked, alarmsHidden, alarmsPresent, dpPattern, aliasPattern, descriptionPattern);

}

fwSystemOverviewAlarmsMasking_addRemoteSystemIntegrityAlarms(string domain, 
                                               string lunit, 
                                               dyn_string& alarms, 
                                               dyn_bool& alarmsMasked,
                                               dyn_bool& alarmsHidden, 
                                               dyn_bool& alarmsPresent, 
                                               string dpPattern = "", 
                                               string aliasPattern = "", 
                                               string descriptionPattern = "")
{
  
  dyn_dyn_string siDps;
 
  string type = "";
  fwCU_getType(lunit, type);
  if(type == "IcemonSystemIntegrity" || type == "IcemonSystemIntegrityCV")
  {
    siDps[1][1] = lunit;
    siDps[1][2] = domain;
  }
  else
  {
    siDps = fwSysOverviewFsm_getChildrenOfTypeWithDomain(lunit, "IcemonSystemIntegrity", domain);   
  }

  for(int i = 1; i <= dynlen(siDps); i++)
  {
    //string unAppDp = icemon_getUnAppDpBySIDp(siDps[i][1]);
    dyn_string descriptions;
    dyn_int active;
    dyn_bool masked, hidden;
    
//    icemon_getApplicationSystemIntegrityAlarms(unAppDp, dpes, descriptions, active, masked, hidden, values, statistics, remotelyMasked);
    dyn_string siAlarms;
	if(isFunctionDefined("icemon_getLocallyStoredSIAlarms"))
	{
     icemon_getLocallyStoredSIAlarms(siDps[i][1], siAlarms, descriptions, masked, hidden, active);    
	}
    
    for ( int j=1; j<=dynlen(siAlarms); j++)
    {
      if (dpPattern != "" && !patternMatch("*" + dpPattern + "*", siAlarms[j]))
        continue;

      if (aliasPattern != "" &&!patternMatch("*" + aliasPattern + "*", dpGetAlias(siAlarms[j])))
        continue;
      
      if (descriptionPattern != "" &&!patternMatch("*" + descriptionPattern + "*", dpGetDescription(siAlarms[j])))
        continue;

        dynAppend(alarms, siAlarms[j]);
        dynAppend(alarmsPresent, active[j]);
        dynAppend(alarmsMasked, masked[j]);
        dynAppend(alarmsHidden, hidden[j]);
      }
  }
  
}

