/** Sets all the information about the managers in project. 
    Note: The relation between data from all the arrays is based on the Index of the array.
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param projDp        Project datapoint name
@param type          Array of manager types
@param num           Array of manager number
@param opt           Array of manager options
@param mode          Array of manager startup mode
@param index         Array of managet index
@param cStat         Array of current state of managers
@param okStat        Array of Ok States of manager as defined in the configuration file. This array can be shorter than the other arrays
@param pid           Array of process ids of manager
@param resetMin      Array of reset start counter for manager
@param restart       Array of restart for manager
@param secKill       Array of Seconds to Kill for manager
@param startTime     Array of start time for manager
@param lastUpdated   Array of flags that indicated if the manager was updated during the last PMON scan

* @deprecated 2018-07-24

*/

#uses "fwInstallation/fwInstallation.ctl"

int fwSystemOverviewFunc_setProjManagersData(string projDp, dyn_string type, dyn_int num, dyn_string opt, dyn_uint mode, dyn_uint index, dyn_int cStat, dyn_int okStat,
                        dyn_int pid, dyn_uint resetMin, dyn_uint restart, dyn_uint secKill, dyn_time startTime, dyn_bool lastUpdated)
{
  FWDEPRECATED();

  dyn_string dpNameList;
  dyn_anytype value;
  
  dpNameList[1] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_OK_STATE_STR; value[1] = okStat;
  dpNameList[2] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_NUM_STR; value[2] = num;   
  dpNameList[3] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_TYPE_STR; value[3] = type;
  dpNameList[4] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_INDEX_STR; value[4] = index;
  dpNameList[5] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_MODE_STR; value[5] = mode; 
  dpNameList[6] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_OPTIONS_STR; value[6] = opt;
  dpNameList[7] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_PID_STR; value[7] = pid;
  dpNameList[8] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_RESETMIN_STR; value[8] = resetMin;
  dpNameList[9] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_RESTART_STR; value[9] = restart;
  dpNameList[10] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_SECKILL_STR; value[10] = secKill;
  dpNameList[11] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_STARTTIME_STR; value[11] = startTime;
  dpNameList[12] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_CURR_STATE_STR; value[12] = cStat;
  dpNameList[13] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_UPDATED_STR; value[13] = lastUpdated; 
  
  return dpSet(dpNameList, value);
}



/** Split the string delimiting on the tag
returns the splitted string. The first string array contains the text outside the 'tag' block
    
    NOTE: This is one of the functions to read configuration information, save data in 
    datapoint and initialise the data structure required by fwSystemOverview tool

@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param source  Input string which is to be splitted

@param tag     Tag string based on which the string is to be splitted

@param result  The splitted string is retirned. The first index contains the string outside the 'tag' block

* @deprecated 2018-07-24

*/

bool fwSystemOverviewFunc_strTagSplit(string source, string tag, dyn_string& result)
{
  FWDEPRECATED();

  dyn_string ds;
  string str, tempStr;

  int pos;
  bool isEnclosed = false;

  //Remove first and last newline, tab, spaces
  source = strltrim(source,"\n\t ");
  source = strrtrim(source,"\n\t ");

  pos = strpos(source, tag);
  if(pos == -1){
    DebugN("strTagSplit: No " + tag + " tag found");
    return false;
  }
  while( pos != -1){
    if(pos > 0){
      tempStr = substr(source, 0, pos);
      tempStr = strrtrim(tempStr,"\n\t ");

      if(isEnclosed)
        dynAppend(ds, tempStr);
      else
        str += tempStr;
    }
    isEnclosed = !isEnclosed;
    source = substr(source, pos+strlen(tag));
    source = strltrim(source,"\n\t ");
    pos = strpos(source, tag);
  }
  
  if(strlen(source) > 0)
    str = str + source + "\n";
  
  strreplace(str, "\n\n", "\n");

  dynInsertAt(ds,str,1);

  result = ds;
  
  if(isEnclosed){
    DebugN("in strTagSplit: Mismatch Delimiter: " + tag, "Processed String: " + ds, "String: "+ str);
    return false;
  }
  
  return true;
}


/**Get the parameter of the tag; format 'tag'  = 'variable' which is delimited by newline.
  
    NOTE: This is one of the functions to read configuration information, save data in 
    datapoint and initialise the data structure required by fwSystemOverview tool


@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param  source  String from which the parameter for the tag is to be extracted

@param  tag     The tag which is to be searched in the string

@param  result  Parameter for the tag. If no tag present in the source then blank string is returned

* @deprecated 2018-07-24

*/
bool fwSystemOverviewFunc_strGetParam(string source, string tag, string& result)
{
  FWDEPRECATED();

  string str;
  int beg, end;

  result = str;
  
  beg = strpos(source, tag);
  
  if(beg == -1){
/*    if (showErrorDialog){
      popupMessage("_Ui_1", "in strGetParam: No Tag Found: " + tag  + "in string: " + source);
    }
*/  DebugN("in strGetParam: No Tag Found: " + tag  + "in string: " + source);
    return false;
  }
  
  source = substr(source, beg);
  
  beg = strpos(source, "=");
  if(beg == -1){
    DebugN("in strGetParam: No '=' found in string: " + source);
    return false;
  }
  
  end = strpos(source, "\n");
  if(end == -1){
    DebugN("in strGetParam: No newline character in string: " + source);
    end = strlen(source);
  }

  str = substr(source, beg+1, end-beg-1);

  str = strltrim(str, "\n\t\" ");
  str = strrtrim(str, "\n\t\" ");
  result = str;

  return true;
}


/** Sets the complete project data
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param projDp        Project datapoint name
@param projName      Project name
@param projCStat     Project current status
@param sysNo         System No to which the project belongs
@param pmonPortNo    PMON manager port number
@param eventPortNo   Event manager port number
@param dmPortNo      Data manager port number
@param distPortNo    Distribution manager port number
@param sharedDir     Shared directory path for the project folder
@param hostIp        Host IP address for the project
@param hostName      Host name for the project
@param userName      User name which has access priviledge to the PMON
@param userPassword  Password for the user


* @deprecated 2018-07-24

*/
int fwSystemOverviewFunc_setProjData(string projDp, string projName, int projCStat, unsigned sysNo, unsigned pmonPortNo, unsigned eventPortNo, 
                unsigned dmPortNo, unsigned distPortNo, string sharedDir, string hostIp, string hostName, string userName, string userPassword)
{
  FWDEPRECATED();

  dyn_string dpNameList;
  dyn_anytype value;
  
  dpNameList[1] = projDp + fwSystemOverviewFunc_PROJ_NAME_STR; value[1] = projName; 
  dpNameList[2] = projDp + fwSystemOverviewFunc_SYSNO_STR; value[2] = sysNo; 
  dpNameList[3] = projDp + fwSystemOverviewFunc_PMON_PORT_STR; value[3] = pmonPortNo; 
  dpNameList[4] = projDp + fwSystemOverviewFunc_USER_NAME_STR; value[4] = userName;
  dpNameList[5] = projDp + fwSystemOverviewFunc_USER_PASSWORD_STR; value[5] = userPassword;
  dpNameList[6] = projDp + fwSystemOverviewFunc_EVM_PORT_STR; value[6] = eventPortNo;
  dpNameList[7] = projDp + fwSystemOverviewFunc_DM_PORT_STR; value[7] = dmPortNo;
  dpNameList[8] = projDp + fwSystemOverviewFunc_DISTMAN_PORT_STR; value[8] = distPortNo;
  dpNameList[9] = projDp + fwSystemOverviewFunc_IP_STR; value[9] = hostIp;
  dpNameList[10] = projDp + fwSystemOverviewFunc_HOSTNAME_STR; value[10] = hostName;
  dpNameList[11] = projDp + fwSystemOverviewFunc_PROJ_PATH_STR; value[11] = sharedDir;
  
  return dpSet(dpNameList, value);
}




/** Extracts the manager name, number and the ok state and strores it in the projDp datapoint
  
    NOTE: This is one of the functions to read configuration information, save data in 
    datapoint and initialise the data structure required by fwSystemOverview tool
 
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param ds  String which contained manager information is parsed and the relevant 
           section in projDp datapoint is populated
           
@param projDp  Project datapoint for which the manager information is stored


* @deprecated 2018-07-24

*/
bool fwSystemOverviewFunc_readManInfo(dyn_string ds, string projDp)
{
  FWDEPRECATED();

  dyn_string     ds1;
  dyn_string     ds2;
  
  dyn_int        cStat, okStat, pid, num;
  dyn_uint       index, mode, resetMin, restart, secKill;
  dyn_time       startTime;
  dyn_string     type, opt;
  dyn_bool       lastUpdated;  
      
  if(dynlen(ds)!=1){
    DebugN("in readManInfo: Problem while reading config file. Only one set of Managers tag supported");
    return false;
  }
  strreplace(ds[1]," ","");
  while(strreplace(ds[1],"\n\n", "\n") != 0);
  ds1 = strsplit(ds[1], "\n");
//  DebugN("in readManInfo: ds1=" + ds1);
  
  for(int i = 1; i <= dynlen(ds1); i++){
    ds2 = strsplit(ds1[i], "=,");
    
    dynAppend(type, ds2[1]);
    dynAppend(num, ds2[2]);
    dynAppend(okStat, ds2[3]);
    dynAppend(opt, "");
    dynAppend(index, i);
    dynAppend(cStat, fwSystemOverviewFunc_PMON_NOT_RUNNING);
    dynAppend(pid, -1);
    dynAppend(mode, 0);
    dynAppend(startTime, "");
    dynAppend(resetMin, "");
    dynAppend(restart, "");
    dynAppend(secKill, "");
    dynAppend(lastUpdated, FALSE);
  }
  
  fwSystemOverviewFunc_setProjManagersData(projDp, type, num, opt, mode, index, cStat, okStat, pid, resetMin, restart, secKill, startTime, lastUpdated);
  
  return true;
}


/** Make project datapoint name
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param sysNo        System number
@param dpHostName   Host name with . replaced by undersore
@param pmonPortNo   PMON port number
* @deprecated 2018-07-24

*/
string fwSystemOverviewFunc_makeProjDpName(unsigned sysNo, string dpHostName, unsigned pmonPortNo)
{
  FWDEPRECATED();
  return fwSystemOverviewFunc_PROJVIEW_NODE+sysNo+"_"+dpHostName+"_"+pmonPortNo;
}

/** Sets system current state
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param sysDp   System datapoint name
@param sysState  Current system state


* @deprecated 2018-07-24

*/
int fwSystemOverviewFunc_setSysState(string sysDp, unsigned sysState)
{
  FWDEPRECATED();
  return dpSet(sysDp + fwSystemOverviewFunc_CURR_STATE_STR, sysState);
}

/** Sets the parent system number for a system datapoint
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param sysDp        System datapoint name
@param parentSysNo  Parent system number  


* @deprecated 2018-07-24

*/
int fwSystemOverviewFunc_setSysParentNode(string sysDp, unsigned parentSysNo)
{
  FWDEPRECATED();
  
  return dpSet(sysDp + fwSystemOverviewFunc_PARENT_STR, parentSysNo);
}



/** @deprecated 2018-07-24

*/
bool fwSystemOverviewFunc_readProjParam(string projStr, unsigned sysNo, string& projDp)
{
  FWDEPRECATED();

  dyn_string ds;
  
  string hostIP, hostName, userName, userPassword, projPath, projName;
  string tempStr, dpHostName;
  unsigned dmPortNo, evmPortNo, pmonPortNo, distPortNo;
  
  fwSystemOverviewFunc_strTagSplit(projStr, "[managers]", ds);
  
  if(strlen(ds[1]) == 0){
    DebugN("in readProjParam: No project variables available");
    return false;
  }
  
  fwSystemOverviewFunc_strGetParam(ds[1], "hostIP", hostIP);
  fwSystemOverviewFunc_strGetParam(ds[1], "hostName", hostName);
  fwSystemOverviewFunc_strGetParam(ds[1], "projectName", projName);
  fwSystemOverviewFunc_strGetParam(ds[1], "sharedDir", projPath);
  fwSystemOverviewFunc_strGetParam(ds[1], "userName", userName);
  fwSystemOverviewFunc_strGetParam(ds[1], "userPassword", userPassword);
  
  fwSystemOverviewFunc_strGetParam(ds[1], "pmonPort", tempStr);
  if(strlen(tempStr) == 0 || strtolower(tempStr) == "null")
    pmonPortNo = 0;
  else if(strtolower(tempStr) == "default")
    pmonPortNo = 4999;
  else
    pmonPortNo = tempStr;
  
  fwSystemOverviewFunc_strGetParam(ds[1], "dmPort", tempStr);
  if(strlen(tempStr) == 0 || strtolower(tempStr) == "null")
    dmPortNo = 0;
  else if(strtolower(tempStr) == "default")
    dmPortNo = 4897;
  else
    dmPortNo = tempStr;
  
  fwSystemOverviewFunc_strGetParam(ds[1], "evmPort", tempStr);
  if(strlen(tempStr) == 0 || strtolower(tempStr) == "null")
    evmPortNo = 0;
  else if(strtolower(tempStr) == "default")
    evmPortNo = 4998;
  else
    evmPortNo = tempStr;
  
  fwSystemOverviewFunc_strGetParam(ds[1], "distPort", tempStr);
  if(strlen(tempStr) == 0 || strtolower(tempStr) == "null")
    distPortNo = 0;
  else if(strtolower(tempStr) == "default")
    distPortNo = 4777;
  else
    distPortNo = tempStr;
  
  if(pmonPortNo ==0 || (strlen(hostIP) ==0 && strlen(hostName) == 0)){
    DebugN("in readProjParam: Blank pmonPort munber or blank Host Address and Name");
    return false;
  }
  else if(flagGetIP && strlen(hostIP) == 0 && strlen(hostName) > 0)
    hostIP = getHostByName(hostName);
  else if(flagGetHost && strlen(hostName) == 0 && strlen(hostIP) > 0)
    hostName = getHostByAddr(hostIP);
  
  dpHostName = hostName;
  strreplace(dpHostName, ".", "_");
  
  
  projDp = fwSystemOverviewFunc_makeProjDpName(sysNo, dpHostName, pmonPortNo);
  
  if(!dpExists(projDp)){
    dpCreate(projDp, fwSystemOverviewFunc_PROJ_NODE_TYPE);
  }

  fwSystemOverviewFunc_setProjData(projDp, projName, fwSystemOverviewFunc_PMON_NOT_RUNNING, sysNo, pmonPortNo, evmPortNo, dmPortNo, distPortNo, projPath, hostIP, hostName, userName, userPassword);
  
  dynRemove(ds, 1);
  if(!fwSystemOverviewFunc_readManInfo(ds, projDp)){
    DebugN("in readProjParam: Problem while reading Managers Info");
    return false;
  }
  return true;
}


/** Set system datapoint data
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param sysDp    System datapoint name
@param sysNo    System number
@param sysName  System Name
@param parentNo Parent system number
@param projDpList  List of projet datapoints in the system


** @deprecated 2018-07-24

*/

int fwSystemOverviewFunc_setSysNodeData(string sysDp, unsigned sysNo, string sysName, unsigned parentNo, dyn_string projDpList)
{
  FWDEPRECATED();
  return dpSet(sysDp + fwSystemOverviewFunc_SYSNO_STR, sysNo, 
               sysDp + fwSystemOverviewFunc_SYSNAME_STR , sysName,
               sysDp + fwSystemOverviewFunc_PARENT_STR , parentNo,
               sysDp + fwSystemOverviewFunc_PROJLIST_STR , projDpList);
}


/** Set childrens of a PVSS system
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param sysDp      System datapoint name
@param childNodes Childrens system nodes for sysDp 
** @deprecated 2018-07-24

*/
int fwSystemOverviewFunc_setSysChildNodes(string sysDp, dyn_uint childNodes)
{
  FWDEPRECATED();

  return dpSet(sysDp + fwSystemOverviewFunc_CHILD_STR, childNodes);
}


/** Computes the project state and sets all the information about the managers and the project
    state and name in project datapoint 
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param projDp        Project datapoint name
@param acProjName    Actual Project name as reported by PMON
@param type          Array of manager types
@param num           Array of manager number
@param opt           Array of manager options
@param mode          Array of manager startup mode
@param index         Array of managet index
@param cStat         Array of current state of managers
@param pid           Array of process ids of manager
@param resetMin      Array of reset start counter for manager
@param restart       Array of restart for manager
@param secKill       Array of Seconds to Kill for manager
@param startTime     Array of start time for manager
@param lastUpdated   Array of flags that indicated if the manager was updated during the last PMON scan


** @deprecated 2018-07-24

*/
int fwSystemOverviewFunc_setProjDataNState(string projDp, string actProjName, dyn_string& type, dyn_int& num, dyn_string& opt, dyn_uint& mode, dyn_uint& index, dyn_int& cStat, 
                        dyn_int& pid, dyn_uint& resetMin, dyn_uint& restart, dyn_uint& secKill, dyn_time& startTime, dyn_bool lastUpdated)
{
  FWDEPRECATED();

  dyn_int okStat;
  dyn_bool mask;
  int projCStat, sysCStat;
  string projName;
  int i;
  
  dyn_string dpNameList;
  dyn_anytype value;
  
  bool useMask = TRUE;      /// Hardcoded to check only the requested managers for updating the project state.
  
  dpGet(projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_OK_STATE_STR, okStat,
        projDp + fwSystemOverviewFunc_PROJ_NAME_STR, projName);
  
      
  for(i = 1; i <= dynlen(cStat); i++){
    if(dynlen(okStat) >= i && lastUpdated[i] == TRUE)
      dynAppend(mask, TRUE);
    else
      dynAppend(mask, FALSE);
    
    if(cStat[i] == 0){
      if (pid[i] == -1)
        cStat[i] = (mode[i] == PMON_START_MANUAL) ? 0 : fwSystemOverviewFunc_STOPPED_ABNORMAL;
      else if (pid[i] == -2)   // restarting too rapidly
        cStat[i] = fwSystemOverviewFunc_RAPID_RESTART;
    }
  }

  if(useMask)
    projCStat = dynMax(cStat, mask);
  else
    projCStat = dynMax(cStat);
  
  if(projName != actProjName)
    projCStat = fwSystemOverviewFunc_PROJNAME_MISMATCH;

  dpNameList[1] = projDp + fwSystemOverviewFunc_CURR_STATE_STR; value[1] = projCStat;
  dpNameList[2] = projDp + fwSystemOverviewFunc_ACT_PROJ_NAME_STR; value[2] = actProjName;
  dpNameList[3] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_NUM_STR; value[3] = num;   
  dpNameList[4] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_TYPE_STR; value[4] = type;
  dpNameList[5] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_INDEX_STR; value[5] = index;
  dpNameList[6] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_MODE_STR; value[6] = mode; 
  dpNameList[7] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_OPTIONS_STR; value[7] = opt;
  dpNameList[8] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_PID_STR; value[8] = pid;
  dpNameList[9] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_RESETMIN_STR; value[9] = resetMin;
  dpNameList[10] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_RESTART_STR; value[10] = restart;
  dpNameList[11] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_SECKILL_STR; value[11] = secKill;
  dpNameList[12] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_STARTTIME_STR; value[12] = startTime;
  dpNameList[13] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_CURR_STATE_STR; value[13] = cStat;
  dpNameList[14] = projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_UPDATED_STR; value[14] = lastUpdated; 
  
  return dpSet(dpNameList, value);
}


/** Reads the information delimited between the [project] tag and populates the
    datapoint for the projects in a system
  
    NOTE: This is one of the functions to read configuration information, save data in 
    datapoint and initialise the data structure required by fwSystemOverview tool

@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param ds   Dynamic string containing information on projects under one PVSS system,
            which is parsed and populated in datapoint of each project for a system
            
@param sysNo  The number of the system for which the projects are configured

@param projDpList  The list of datapoint names of the projects in a system in which the config information is stored



** @deprecated 2018-07-24

*/
bool fwSystemOverviewFunc_readProjInfo(dyn_string ds, unsigned sysNo, dyn_string& projDpList)
{
  FWDEPRECATED();

  string projDp;
  
  for(int i = 1; i <= dynlen(ds); i++){
    if(!fwSystemOverviewFunc_readProjParam(ds[i], sysNo, projDp)){
      DebugN("in readProjInfo: Could not read Project Parameters from config file");
      return false;
    }
    if(strlen(projDp) > 0)
      dynAppend(projDpList, projDp);
    projDp = "";
  }
  return true;
}





/** Get childrens of a PVSS system
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param sysDp      System datapoint name
@param childNodes Childrens system nodes of sysDp 


** @deprecated 2018-07-24

*/
int fwSystemOverviewFunc_getSysChildNodes(string sysDp, dyn_uint& childNodes)
{
  FWDEPRECATED();

  return dpGet(sysDp + fwSystemOverviewFunc_CHILD_STR, childNodes);
}


/** Reads the parameters between the [system] tag in the config file

    NOTE: This is one of the functions to read configuration information, save data in 
    datapoint and initialise the data structure required by fwSystemOverview tool
 
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param  sysStr  String which contained system parameters is parsed and the sysDp datapoint is populated

@param  sysDp   Datapoint name where the parsed system information is stored

** @deprecated 2018-07-24

*/
bool fwSystemOverviewFunc_readSysParam(string sysStr, string& sysDp) 
{
  FWDEPRECATED();

  dyn_string   ds;
  string       tempStr;
  
  dyn_string   projDpList;
  unsigned     sysNo;
  string       sysName;
  unsigned     parentNo;
  dyn_uint     childNodes;
  

  fwSystemOverviewFunc_strTagSplit(sysStr, "[project]", ds);
  
  if(!fwSystemOverviewFunc_strGetParam(ds[1], "sysNo", tempStr)){
    DebugN("in readSysParam: No SysNo defined in Config file");
    return false;
  }
  
  sysNo = tempStr;
  
  fwSystemOverviewFunc_strGetParam(ds[1], "sysName", sysName);
  
  fwSystemOverviewFunc_strGetParam(ds[1], "parentSysNo", tempStr);

  if(strtolower(tempStr) == "null" || tempStr == "0")
    parentNo = 0;
  else
    parentNo = tempStr;
    
  dynRemove(ds, 1);
  
  if(!fwSystemOverviewFunc_readProjInfo(ds, sysNo, projDpList)){
    for(int i = 1; i < dynlen(projDpList); i++){
      if(dpExists(projDpList[i]))
        dpDelete(projDpList[i]);
    }
    DebugN("in readSysParam: Could not read Project Info from config");
    return false;
  }
  
  sysDp = fwSystemOverviewFunc_sysNoToDp(sysNo);
  
  if(!dpExists(sysDp)){
    dpCreate(sysDp, fwSystemOverviewFunc_SYS_NODE_TYPE);
  }
  
  fwSystemOverviewFunc_setSysNodeData(sysDp, sysNo, sysName, parentNo, projDpList);
  fwSystemOverviewFunc_setSysChildNodes(sysDp, childNodes);
  fwSystemOverviewFunc_setSysState(sysDp, fwSystemOverviewFunc_PMON_NOT_RUNNING);
  
  return true;
} 


/** Poll's the PMON port of the project and populate the corresponding manager data in the projDp datapoint.
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param projDp  The datapoint name of the project whose PMON is to be polled.

** @deprecated 2018-07-24

*/
bool fwSystemOverviewFunc_pollProject(string projDp)
{
  FWDEPRECATED();

  dyn_string ipAddr, userName, userPassword;
  unsigned sysNo;
  unsigned pMonPort;
  string sharedDir;
  bool isPolling = false;
  int manCount, i, matchCount, j, k;
  
  int currProjStat;

  int            err;
  dyn_dyn_string ddsResult, ddsResultStati;
  dyn_bool       pat1, pat2, pat3;
  dyn_string     typeTemp, numTemp;
  
  dyn_int        cStat, okStat, pid, num;
  dyn_uint       index, mode, resetMin, restart, secKill;
  dyn_time       startTime;
  dyn_string     type, opt;
  dyn_bool       lastUpdated;  
  string         actProjName;
  
//  DebugN("In fwSystemOverviewFunc_pollProject: Called", projDp);
  
//using one common mutex for all the projects. However can think of another way to avoid deadlocks while accessing IsPolling Flag
  if (projDp != ""){
    synchronized(fwSystemOverviewFunc_mutex){
      fwSystemOverviewFunc_getIsPolling(projDp, isPolling);
      fwSystemOverviewFunc_setIsPolling(projDp, TRUE);
    }
    
    if(isPolling == TRUE)
      return false;
     
    fwSystemOverviewFunc_getProjAccessData(projDp, ipAddr, pMonPort, userName,userPassword, sharedDir);
    fwSystemOverviewFunc_getProjManagersData(projDp, type, num, opt, mode, index, cStat, okStat, pid, resetMin, restart, secKill, startTime, lastUpdated);   
    
    for(j = 1; j <= dynlen(type); j++){
      typeTemp[j] = strtolower(type[j]);
      numTemp[j] = num[j];
      lastUpdated[j] = FALSE;
    }
  }
  else{
    DebugN("Error in pollProject: NULL DP");
    return false;
  }
  
  if((err = pmon_query(userName+"#"+userPassword+"#PROJECT:", ipAddr, pMonPort, ddsResult, false, true)) == false){
    if(strlen(ddsResult[1][1]) > 0){
      actProjName = ddsResult[1][1];
      err = pmon_query(userName+"#"+userPassword+"#MGRLIST:LIST", ipAddr, pMonPort, ddsResult, true, true);
      err = pmon_query(userName+"#"+userPassword+"#MGRLIST:STATI", ipAddr, pMonPort, ddsResultStati, true, true);
  
      if ( err )
      {
        pmon_warningOutput("In pollProject: errPmonNotRunning", -1, false);
        //return;
      }
      else{
        manCount = dynlen(ddsResult);
        for (i = 1; i <= manCount; i++)        // to include code for updating the changed status of the managers
        {
//          if ( !isMotif() ) strreplace(ddsResult[i][1], "&", "&&");
          strreplace(ddsResult[i][1], "&", "&&");
          pat1 = patternMatch(strtolower(ddsResult[i][1]), typeTemp);
          pat2 = patternMatch((int)ddsResultStati[i][5], numTemp);
          
          for(k = 1; k <= dynlen(pat1); k++){  // Considering that the Manager type and Num forms a unique ID adding to array. 
            pat3[k] = pat1[k] & pat2[k];      // Otherwise option field can also be considered. 
          }
          matchCount = dynCount(pat3, TRUE);
          if(matchCount == 0){
            dynAppend(type, ddsResult[i][1]);
            dynAppend(opt, ( dynlen(ddsResult[i]) > 5)?ddsResult[i][6]:"");
            dynAppend(index, i);
            dynAppend(cStat, ddsResultStati[i][1]);
            dynAppend(pid, ddsResultStati[i][2]);
            dynAppend(mode, ddsResultStati[i][3]);
            dynAppend(startTime, ddsResultStati[i][4]);
            dynAppend(num, ddsResultStati[i][5]);
            dynAppend(resetMin, ddsResult[i][4]);
            dynAppend(restart, ddsResult[i][5]);
            dynAppend(secKill, ddsResult[i][3]);
            dynAppend(lastUpdated, TRUE);
          }
          else {
            for(k = 1; k <= matchCount; k++){
              j = dynContains(pat3, TRUE);
              pat3[j] = FALSE;
              if (lastUpdated[j] == FALSE)
                break;
            }
             
            if(k <= matchCount){
              type[j] = ddsResult[i][1];
              opt[j] = ( dynlen(ddsResult[i]) > 5)?ddsResult[i][6]:"";
              index[j] = i;
              cStat[j] = ddsResultStati[i][1];
              pid[j] = ddsResultStati[i][2];
              mode[j] = ddsResultStati[i][3];
              startTime[j] = ddsResultStati[i][4];
              num[j] = ddsResultStati[i][5];
              resetMin[j] = ddsResult[i][4];
              restart[j] = ddsResult[i][5];
              secKill[j] = ddsResult[i][3];
              lastUpdated[j] = TRUE;
            }
            else{
              dynAppend(type, ddsResult[i][1]);
              dynAppend(opt, ( dynlen(ddsResult[i]) > 5)?ddsResult[i][6]:"");
              dynAppend(index, i);
              dynAppend(cStat, ddsResultStati[i][1]);
              dynAppend(pid, ddsResultStati[i][2]);
              dynAppend(mode, ddsResultStati[i][3]);
              dynAppend(startTime, ddsResultStati[i][4]);
              dynAppend(num, ddsResultStati[i][5]);
              dynAppend(resetMin, ddsResult[i][4]);
              dynAppend(restart, ddsResult[i][5]);
              dynAppend(secKill, ddsResult[i][3]);
              dynAppend(lastUpdated, TRUE);
            }              
          }
        }
      }
      fwSystemOverviewFunc_setProjDataNState(projDp, actProjName, type, num, opt, mode, index, cStat, pid, resetMin, restart, secKill, startTime, lastUpdated);   // for comman manager struct
    }
    else{
//    DebugTN("PMON NOT RESPONDING: ",projDp, ddsResult);
      fwSystemOverviewFunc_setProjPmonNotResponding(projDp);
    }
  }
  else{
//    DebugTN("PMON NOT RUNNING: ",projDp, ddsResult);
    fwSystemOverviewFunc_setProjPmonNotRunning(projDp);
  }
//  DebugN("in pollProject: "+projDp, err);
  fwSystemOverviewFunc_setIsPolling(projDp, FALSE);
}



/** Get project current state
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param projDp    Project datapoint name
@param projCState Project current state

** @deprecated 2018-07-24

*/
int fwSystemOverviewFunc_getProjState(string projDp, unsigned& projCState)
{
  FWDEPRECATED();
  
  return dpGet(projDp + fwSystemOverviewFunc_CURR_STATE_STR, projCState);
}



/** Builds the system interconnection graph, based on the parent system no given for each system configuration.
  
    NOTE: This is one of the functions to read configuration information, save data in 
    datapoint and initialise the data structure required by fwSystemOverview tool
 
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param sysDpList The list of system datapoints for which the interconnect graph is to be created.


** @deprecated 2018-07-24
*/
bool fwSystemOverviewFunc_buildSysGraph(dyn_string sysDpList)
{

  FWDEPRECATED();

  dyn_uint leafNodes, orphanNodes, floatingNodes, intermediateNodes;
  dyn_dyn_string misdirectedNodes;
  unsigned presentSystemNo, parentNo;
  dyn_uint childNodes;
  string sysName, sysDp;
  dyn_string projDpList;
  
  int j;
 
  // populate child array of each node
  for(j = 1; j <= dynlen(sysDpList); j++){
    
    fwSystemOverviewFunc_getSysData(sysDpList[j], presentSystemNo, sysName, parentNo, childNodes, projDpList);

    if(parentNo == 0){
      continue;
    }
    
    sysDp = fwSystemOverviewFunc_sysNoToDp(parentNo);
    
    if(!dpExists(sysDp)){
      dynAppend(misdirectedNodes[j], parentNo);      //remove the link from the DP and add it to misdirected list
      parentNo = 0;
      fwSystemOverviewFunc_setSysParentNode(sysDpList[j], parentNo);
      continue;
    }
    
    fwSystemOverviewFunc_getSysChildNodes(sysDp, childNodes);
    
    if(dynContains(childNodes, presentSystemNo) == 0)                //the list of the childrens in the parent list
      dynAppend(childNodes, presentSystemNo); 
    
    dynSortAsc(childNodes);
    
    fwSystemOverviewFunc_setSysChildNodes(sysDp, childNodes);//    dpSet(SYSVIEW_NODE + parentNo + CHILD_STR, childNodes);
  }
//  DebugN(dpNameList);

  for(j = 1; j <= dynlen(sysDpList); j++){
    
    fwSystemOverviewFunc_getSysData(sysDpList[j], presentSystemNo, sysName, parentNo, childNodes, projDpList);
//    DebugN(parentNo, childNodes, presentSystemNo);
    
    if(parentNo == 0 && dynlen(childNodes) == 0 && dynContains(floatingNodes, presentSystemNo) == 0)
       dynAppend(floatingNodes, presentSystemNo);
    else if(parentNo != 0 && dynlen(childNodes) == 0 && dynContains(leafNodes, presentSystemNo) == 0)
       dynAppend(leafNodes, presentSystemNo);
    else if(parentNo == 0 && dynlen(childNodes) != 0 && dynContains(orphanNodes, presentSystemNo) == 0)
       dynAppend(orphanNodes, presentSystemNo);
    else if(parentNo != 0 && dynlen(childNodes) != 0 && dynContains(intermediateNodes, presentSystemNo) == 0)
       dynAppend(intermediateNodes, presentSystemNo);
  }
  DebugN("PARENTS: " + orphanNodes + " CHILDRENS: "+ leafNodes + " FLOATING: " + floatingNodes + " INTERMEDIATE: " + intermediateNodes);
  
  if(dynlen(misdirectedNodes) > 0) 
    for(int i = 1; i <= dynlen(sysDpList); i++)
      if(dynlen(misdirectedNodes[i]) > 0)
        DebugN("DP NAME: " + sysDpList[i] + " MIS-DIRECTED: " + misdirectedNodes[i]);
}


/** @deprecated 2018-07-24
*/
string fwSysOverviewNotifications_getDp(string application)
{
  FWDEPRECATED();

  return smsConfigDpPrefix + strtoupper(application);
}

/** @deprecated 2018-07-24
*/
int fwSysOverviewLongTermReport_generateOverviews()
{
  FWDEPRECATED();

  fwInstallationDB_connect();
  string path = gWebPath + "projectsOverview/";
  
  // Projects overview
  dyn_dyn_mixed projectsInfo;
  fwInstallationDB_getProjectsOverview(projectsInfo);
  fwSystemOverview_saveProjectsInfo2Xml(path + "projectsOverview.xml", projectsInfo);
  
  // Hosts overview
  dyn_dyn_mixed hostsInfo;
  fwInstallationDB_getHostsOverview(hostsInfo);
  fwSystemOverview_saveHostsInfo2Xml(path + "hostsOverview.xml", hostsInfo);
  
  // File Issues overview
  dyn_dyn_mixed filesInfo;
  fwInstallationDB_getFilesOverview(filesInfo);
  fwSystemOverview_saveFilesInfo2Xml(path + "fileIssuesOverview.xml", filesInfo);
  
  return 0;  
}



/** @deprecated 2018-07-24
*/
dyn_string fwSysOverviewLongTermReport_createApplicationFSRootCharts(string application, time endDate, int days, bool plotOnTheSameChart = true)
{
  FWDEPRECATED();

  return _fwSysOverviewLongTermReport_createApplicationFSCharts(application, endDate, days, "/", "FS /", plotOnTheSameChart);
}


/** @deprecated 2018-07-24
*/
string fwGoogleApi_barChart(string title, string xAxis, dyn_dyn_mixed data, int x = 1000, int y= 500)
{
  FWDEPRECATED();

  string html = "<html>";
  html += " <head>";
  html += "   <script type=\"text/javascript\" src=\"https://www.google.com/jsapi\"></script>";
  html += "   <script type=\"text/javascript\">";
  html += "     google.load(\"visualization\", \"1\", {packages:[\"corechart\"]});";
  html += "     google.setOnLoadCallback(drawChart);";
  html += "     function drawChart() {";
  html += "       var data = google.visualization.arrayToDataTable(";
  html += fwGoogleApi_getDataMatrix(data);  
  html += "       );";
  html += "       var options = {";
  html += "         chartArea:{left:100},";
  html += "         title: \'" + title + "\',";
  html += "         vAxis: {title: \'" + xAxis + "\',  titleTextStyle: {color: \'red\'}}";
  html += "       };";
  html += "       var chart = new google.visualization.BarChart(document.getElementById(\'chart_div\'));";
  html += "       chart.draw(data, options);";
  html += "     }";
  html += "   </script>";
  html += " </head>";
  html += " <body>";
  html += "   <div id=\"chart_div\" style=\"width: "+x+"px; height: "+y+"px;\"></div>";
  html += " </body>";
  html += "</html>";
 
 return html;
}


/** @deprecated 2018-07-24
*/

string fwGoogleApi_areaChart(string title, string xAxis, dyn_dyn_mixed data, int x = 1000, int y= 500)
{
  FWDEPRECATED();

  string html = "<html>";
  html += " <head>";
  html += "   <script type=\"text/javascript\" src=\"https://www.google.com/jsapi\"></script>";
  html += "   <script type=\"text/javascript\">";
  html += "     google.load(\"visualization\", \"1\", {packages:[\"corechart\"]});";
  html += "     google.setOnLoadCallback(drawChart);";
  html += "     function drawChart() {";
  html += "       var data = google.visualization.arrayToDataTable(";
  html += fwGoogleApi_getDataMatrix(data);    
  html += "       );";
  html += "       var options = {";
  html += "         chartArea:{left:100},";
  html += "         title: \'"+title+"\',";
  html += "         hAxis: {title: \'"+xAxis+"\',  titleTextStyle: {color: \'red\'}}";
  html += "       };";
  html += "       var chart = new google.visualization.AreaChart(document.getElementById(\'chart_div\'));";
  html += "       chart.draw(data, options);";
  html += "     }";
  html += "   </script>";
  html += " </head>";
  html += " <body>";
  html += "   <div id=\"chart_div\" style=\"width: "+x+"px; height: "+y+"px;\"></div>";
  html += " </body>";
  html += "</html>";
 
 return html;
 
}


/** Get list of defined states
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param stateList  Defined states

** @deprecated 2018-07-24


*/

void fwSystemOverviewFunc_getStateList(dyn_int& stateList)
{
  FWDEPRECATED();

  for(int i = -20; i <= 30; i++){
    if(fwSystemOverviewFunc_getStrFromState(i) != "STATE NOT DEFINED")
      dynAppend(stateList, i);
  }
}


/** Extracts the information of each PVSS System from the dyn_string and puts the same 
    in the data points. It also builds a graph for the experiment system. 
    
    NOTE: This is one of the functions to read configuration information, save data in 
    datapoint and initialise the data structure required by fwSystemOverview tool
    
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param ds  Dynamic string which consists of information in string format for all the 
           PVSS System, string at each index consists of information for one system.
           
@param sysDpList List of datapoints where the system information is kept
       
** @deprecated 2018-07-24

*/
bool fwSystemOverviewFunc_readSysInfo(dyn_string ds, dyn_string& sysDpList)
{
  FWDEPRECATED();

  string sysDp;
  
  for(int i = 1; i<= dynlen(ds); i++){
    if(!fwSystemOverviewFunc_readSysParam(ds[i], sysDp)){
      DebugN("in readSysInfo: Error in readSysParam");
      return false;
    }
    dynAppend(sysDpList, sysDp);
  }
  
  fwSystemOverviewFunc_buildSysGraph(sysDpList);
  
  return true;  
}

/** Updates the state of the system based on the states of the projects in the system.
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param sysDp  The datapoint name for which the state is to be updated

** @deprecated 2018-07-24


*/

int fwSystemOverviewFunc_updateSysState(string sysDp)
{
  FWDEPRECATED();

  dyn_string projDpList;
  int projCStat, sysCStat;
  
  fwSystemOverviewFunc_getProjDPList(sysDp, projDpList);
  for(int j = 1; j <= dynlen(projDpList); j++){
    fwSystemOverviewFunc_getProjState(projDpList[j], projCStat);
    if(j == 1){
      sysCStat = projCStat;
    }
    else if(projCStat > sysCStat){
      sysCStat = projCStat;
    }
  }
  fwSystemOverviewFunc_setSysState(sysDp, sysCStat);
}



/** Work function which polls the PMON port of the project and updates the manager states in the project datapoint
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param dpeName   The name of the datapoint element, on whose change this work function is called

@param value     The value of the datapoint element. Not used!

** @deprecated 2018-07-24


*/
int fwSystemOverviewFunc_wfPollProject(string dpeName, bool value)
{
  FWDEPRECATED();

  string projDp = dpeName;
  
  strreplace(projDp, getSystemName(), "");
  strreplace(projDp, fwSystemOverviewFunc_POLL_PROJ_STR + ":_online.._value", "");
  fwSystemOverviewFunc_pollProject(projDp);
}


/** Set array of system datapoints name 
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param sysDpList  Array of system datapoints names

** @deprecated 2018-07-24

*/

int fwSystemOverviewFunc_setSysDPList(dyn_string sysDpList)
{
  FWDEPRECATED();

  return dpSet(fwSystemOverviewFunc_DPNAME_ARRAY + fwSystemOverviewFunc_SYSLIST_STR, sysDpList);
}


/** Set rate for polling
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param refRate    Refresh rate in second

** @deprecated 2018-07-24

*/
int fwSystemOverviewFunc_setRefreshRate(unsigned refRate)
{
  FWDEPRECATED();
  
  return dpSet(fwSystemOverviewFunc_DPNAME_ARRAY + fwSystemOverviewFunc_REFRESH_RATE_STR, refRate);
}



/** Get system name
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param sysDp    System datapoint name
@param sysName  System name

** @deprecated 2018-07-24


*/
int fwSystemOverviewFunc_getSysName(string sysDp, string& sysName)
{
  FWDEPRECATED();
  
  return dpGet(sysDp + fwSystemOverviewFunc_SYSNAME_STR , sysName);
}



/** Get array of system datapoints name registered by the last readConfig function
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param sysDpList  Array of system datapoints names

** @deprecated 2018-07-24

*/

int fwSystemOverviewFunc_getSysDPList(dyn_string& sysDpList)
{
  FWDEPRECATED();

  return dpGet(fwSystemOverviewFunc_DPNAME_ARRAY + fwSystemOverviewFunc_SYSLIST_STR, sysDpList);
}



/** Gets the type of managers available in a project.
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param projDp  Project datapoint name
@param type    String array of types of managers in the project

** @deprecated 2018-07-24

*/

int fwSystemOverviewFunc_getProjManagersType(string projDp, dyn_string& type)
{  
  FWDEPRECATED();

  return dpGet(projDp + fwSystemOverviewFunc_MANAGER_STR + fwSystemOverviewFunc_TYPE_STR, type);
}

/** Delete system datapoint
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

@param sysDp    System datapoint name

** @deprecated 2018-07-24

*/

bool fwSystemOverviewFunc_deleteSysDP(string sysDp)
{
  FWDEPRECATED();


  dyn_string projDpList;
  
  fwSystemOverviewFunc_getProjDPList(sysDp, projDpList);

  for(int i = 1; i<= dynlen(projDpList); i++)
   if(dpExists(projDpList[i]))
     dpDelete(projDpList[i]);
  
  if(dpExists(sysDp))
    dpDelete(sysDp);
}

/** Delete fwSystemOverview system collection datapoint
@par Constraints
	None

@par Usage
	Public

@par PVSS managers
	VISION, CTRL

** @deprecated 2018-06-26
*/
bool fwSystemOverviewFunc_deleteCollDP()
{
  FWDEPRECATED();

  if(dpExists(fwSystemOverviewFunc_DPNAME_ARRAY))
      dpDelete(fwSystemOverviewFunc_DPNAME_ARRAY);
}




/* checks whether a system with name - systemName - is connected
   This method is created to overcome the problem in which there is a hardware failure with the host
   and pmon is not responding, but the dist manager still "thinks" it is connected to the system.
   This problem happend with cs-ccr-ciet56 and cs-ccr-q2ds1*/

/** @deprecated 2018-06-26
  
*/
bool fwSysOverview_isSystemConnected(string systemName)
{
  FWDEPRECATED();

  if (systemName == getSystemName())
    return true;
  bool connected = false;
  int sysId = getSystemId(systemName);
  dyn_string projectDpNames, ex;
  if (sysId > 0)
  {
    dyn_int connectedSystemsIds;
    dpGet("_DistManager.State.SystemNums", connectedSystemsIds);
    if (dynContains(connectedSystemsIds, sysId))
    {
      // check whether the state of the project is different thatn PMON_NO_RESPONSE
      strreplace(systemName, ":", "");
      dyn_string dps = dpNames("*/" + strtoupper(systemName), "FwSystemOverviewSystem");
     
      if(dynlen(dps) > 0)
      {
         fwSysOverview_getSystemProjects(dps[1], projectDpNames, ex);
         if (dynlen(ex) == 0)
         {
           for (int i=1; i <=dynlen(projectDpNames); i++)
           {
              string projectState = fwSysOverview_getProjectState(projectDpNames[i]);
              if (projectState != fwSysOverview_getStrFromState(fwSysOverview_PMON_NO_RESPONSE))
                connected = true;
              else
              {
                DebugN("PMON doesn't respond but the system ID is still in _DistManager.State.SystemNums:" + systemName);
                break;
              }
          }
         }
         else
         {
           DebugN(ex);
           DebugN("Cannot find project dp for system " + systemName + ". Asuming that the content of _DistManager.State.SystemNums is correct and returning that the system is connected!");
           connected = true;
         }
      }
      else
      {
        DebugN("Cannot find project dp for system " + systemName + ". Asuming that the content of _DistManager.State.SystemNums is correct and returning that the system is connected!");
        connected = true;
      }
    }
  }
  return connected;  
} 



/** @deprecated 2018-06-26
  
*/
int fwSysOverview_configure()
{
  FWDEPRECATED();

  dyn_dyn_mixed projectInfo;
  dyn_string exceptionInfo;
  bool createAlerts = true, consistent = true;
  
  dyn_string hostsToBeDeleted;
  dyn_dyn_string projectsToBeDeleted;
  
  if(fwSysOverview_getDBInfo(projectInfo, exceptionInfo) == fwSysOverview_ERROR)
    return -1;
  
  fwSysOverview_checkDbConsistency(projectInfo, consistent, hostsToBeDeleted, projectsToBeDeleted, exceptionInfo);
  if(dynlen(exceptionInfo)) {return -1;}

  if(consistent == false)
  {
    dyn_float resultFloat;
    dyn_string resultText;
    
    ChildPanelOnCentralModalReturn("fwSystemOverview/fwSystemOverview_DB_Consistency.pnl", "DB Consistency", makeDynString(), resultFloat, resultText);
  }
  
  openProgressBar("","","Configuring the System Overview Tool", "","", 2); 
  
  for(int i=1; i<=dynlen(projectInfo); i++)
  {
    showProgressBar("Creating data points.", "", "", (100*i)/dynlen(projectInfo));
    
    if(projectInfo[i][fwSysOverview_PROJECT_NAME_IDX] == "" || projectInfo[i][fwSysOverview_PROJECT_HOST_IDX] == "" || 
       projectInfo[i][fwSysOverview_PROJECT_SYSTEM_NAME_IDX] == "")
      continue;
	
    else
    {
      // ATLAS-specific: restrict systems belonging to a subdetector
     //
/*       if (isFunctionDefined("fwAtlas") && strpos(getSystemName(), "ATLGCSSYS")<0) 
      {
        string subdetId = strtoupper(fwAtlas_getSubdetectorId(getSystemName()));
        if (strpos(projectInfo[i][fwSysOverview_PROJECT_SYSTEM_NAME_IDX], subdetId)<0) 
        {
          DebugN("Ignoring PVSS system " + projectInfo[i][fwSysOverview_PROJECT_SYSTEM_NAME_IDX] +" since it is not part of subdetector " + subdetId);
          continue;
        }
      }
*/
      if(isFunctionDefined("fwAtlas"))
      {
        if(!fwSysOverview_checkSystemSubdetector(projectInfo[i][fwSysOverview_PROJECT_SYSTEM_NAME_IDX]))
          continue;
      }
      
      fwSysOverview_createProject(projectInfo[i], createAlerts, exceptionInfo); 
      if(dynlen(exceptionInfo)) {continue ;} 
    }
  }
  closeProgressBar();
  
  dpSet(fwSysOverview_PARAMETRIZATION + fwSysOverview_DB_UPDATE, true);
  
  return fwSysOverview_OK ;
}


/** @deprecated 2018-06-26
  
*/
string fwSysOverview_getHostDpPattern(string dbHost)
{
  FWDEPRECATED();
  string str = dbHost;
  strreplace(str, ".", "_");
  
  return str;  
}

/** @deprecated 2018-06-26
  
*/
int fwSysOverview_getIsPolling(string projDp, bool& isPolling)
{
  FWDEPRECATED();
  return dpGet(projDp + fwSysOverview_PROJECT_IS_POLLING, isPolling);
}


/** @deprecated 2018-06-26
  
*/
void fwSysOverviewNotifications_addAlarmRecipients(string application, string systemName, string alarmDpe, dyn_string recipients)
{
  FWDEPRECATED();

  string notificationDp = fwSysOverviewNotifications_getAlarmNotificationsConfigDp(application, systemName, alarmDpe, true);
  alarmDpe = dpSubStr(alarmDpe, DPSUB_SYS_DP_EL);
  string recipientsStr = (string) recipients;
  strreplace(recipientsStr, " | ", ";");
  if (notificationDp != "")
  {
    dyn_string dpElements, dpeRecipients;
    dpGet(notificationDp + ".dpElements", dpElements,
          notificationDp + ".recipients", dpeRecipients);
    int pos = dynContains(dpElements, alarmDpe);
    if (pos > 0) //update recipients
    {
      dpeRecipients[pos] += ";"+ recipientsStr;
    }
    else
    {
      dynAppend(dpElements, alarmDpe);
      dynAppend(dpeRecipients, recipientsStr);
    }
    
    dpSet(notificationDp + ".dpElements", dpElements,
          notificationDp + ".recipients", dpeRecipients);
  }
}


/** @deprecated 2018-06-26
  
*/
int fwSysOverview_readSystemConfigurationDB() // This function became OBSOLETE
{
  FWDEPRECATED();

  dyn_string projectNames;
  dyn_dyn_mixed systemsInfo;
  dyn_string hostnames,ips,macs,ips2, macs2,bmc_ips,bmc_ips2;
  //dyn_mixed projectProperties;
  int i, j, ierr;
  // int projectId;
  string ip, mac, ip2, mac2, bmc_ip, bmc_ip2, hostName, projectName; 
  dyn_string versions, oss;
  string sysName;
  dyn_mixed systemInfo;
  dyn_dyn_mixed projectsInfo;
  dyn_dyn_mixed hierarchyInfo;
  dyn_string hostDps, result,dpsToDelete;
  dyn_string dpList;  
  dyn_anytype values;
  dyn_dyn_mixed childSystems;
  dyn_string listOfChildren, sysProjects;
  string dpFMCname;
  bool fmc;
  string fmcSystem;
  dyn_string exceptionInfo;
  
  //init connection
   if(fwInstallationDB_connect()!= 0)
    {
     if(myManType() == UI_MAN)
       ChildPanelOnCentral("vision/MessageInfo1", "ERROR: DB Connection failed", makeDynString("$1:DB Connection failed.\nPlease check DB connection parameters"));
       else
          DebugN("ERROR: DB Connection failed. Please check DB connection parameters");
     return fwSysOverview_ERROR;
    }   

   //check if fwFMC is installed
   fmcSystem = fwSysOverview_getFmcSystem();
   fmc = dpExists(fmcSystem + "fwInstallation_fwFMC");
   
  // 1. populate pc information from DB into pvss dps

   fwInstallationDB_getHosts(hostnames, ips, macs, ips2, macs2, bmc_ips, bmc_ips2); 
   
  //list of existing pcs stored in PVSS 
   fwSysOverview_getHosts(hostDps);
  
  //Check if there are dps to delete
  result = dynIntersect(hostnames,hostDps);
  
   
   dynClear(versions);
   dynClear(oss);
   
   for(i=1;i<=dynlen(hostnames);i++)   
   { 
     // ATLAS-specific: restrict systems belonging to a subdetector
     //
     if (isFunctionDefined("fwAtlas") && strpos(getSystemName(), "ATLGCSSYS")<0) {
     string subdetId = strtoupper(fwAtlas_getSubdetectorId(getSystemName()));
     if (strpos(hostnames[i], subdetId)<0) {
        DebugTN("Ignoring machine "+hostnames[i]+" since it is not part of subdetector "+subdetId);
         continue;
     }
   }
  
    fwInstallationDB_getHostProperties(hostnames[i], ip, mac,ip2,mac2, bmc_ip, bmc_ip2);
    
    fwInstallationDB_getPvssVersions(hostnames[i], versions, oss);
    dynUnique(versions);
    dynUnique(oss);

    hostName = hostnames[i];
    
    // remove all "."s in pcName 
    strreplace(hostnames[i], ".", "_");    
    
    if(fmc)
      dpFMCname = fwSysOverview_getFMCdpName(hostnames[i]);
    else
      dpFMCname="";
    
    
    dpCreate(fwSysOverview_SYSTEM_DP + hostnames[i],"FwSystemOverviewPC");
  
    //DebugN(hostnames[i],versions,oss);    
    dpList[1] = fwSysOverview_SYSTEM_DP + hostnames[i] + fwSysOverview_PC_IP; values[1]= ip;
    dpList[2] = fwSysOverview_SYSTEM_DP + hostnames[i] + fwSysOverview_PC_PVSSVERSION; values[2]=versions;
    dpList[3] = fwSysOverview_SYSTEM_DP + hostnames[i] + fwSysOverview_PC_OPSYSTEM; values[3]=oss;    
    dpList[4] = fwSysOverview_SYSTEM_DP + hostnames[i] + fwSysOverview_PC_IPMINAME; values[4]=dpFMCname;
    dpList[5] = fwSysOverview_SYSTEM_DP + hostnames[i] + fwSysOverview_ORIGINAL_HOST_NAME; values[5]=hostName;
                
    dpSet(dpList, values); 
 
  // 2. populate projects information from DB into pvss dps 
   
    fwInstallationDB_getPvssProjects(projectNames, hostName);
 
    for(j=1;j<=dynlen(projectNames);j++)
    {
      // ATLAS-specific: restrict systems belonging to a subdetector
      // fwSysOverview_getSystemProjects()->System does not
      if (isFunctionDefined("fwAtlas") && strpos(getSystemName(), "ATLGCSSYS")<0) {
        string subdetId = strtoupper(fwAtlas_getSubdetectorId(getSystemName()));
        if (strpos(sysName, subdetId)<0) {
          DebugTN("Ignoring project "+sysName+" since it is not part of subdetector "+subdetId);
          continue;
        }
      } 
      
    bool createAlerts = TRUE;  
    fwSysOverview_createProjectDP(projectNames[j], hostName, createAlerts, exceptionInfo);
        
    } 
   }  
   
  // 3. populate system information from DB into pvss dps    
  
  fwInstallationDB_getPvssSystems(systemsInfo);
  
//DebugN("**********dynlen(systemsInfo) = " + dynlen(systemsInfo));  
 
  for(i=1;i<=dynlen(systemsInfo);i++)   
  {  
    sysName = systemsInfo[i][1];
    
    strreplace(sysName, ":", "");
    
    dynClear(projectsInfo);  
    dynClear(systemInfo);  
    dynClear(childSystems);  
    
    // projectsInfo: 1.project name | 2. pc name
    fwInstallationDB_getSystemProjects(sysName, projectsInfo);
    
//if(patternMatch("*ATLCICSCS*", sysName))
//  DebugN(">>>", sysName, projectsInfo); 
  
    if(dynlen(projectsInfo) <= 0) //DB problem. We have a system but there is no project pointing to it.
    {
       DebugN("WARNING: DB inconsistency. Found system with no project: " + sysName + ". This system will be ignored.");
       continue;
    }
       
    dynClear(sysProjects);
    
    for(j=1;j<=dynlen(projectsInfo);j++)
    {
      dynAppend(sysProjects,projectsInfo[j][FW_INSTALLATION_DB_PROJECT_HOST]+"/"+projectsInfo[j][FW_INSTALLATION_DB_PROJECT_NAME]);
     }
    
   // fwInstallationDB_getSystemHierarchy(hierarchyInfo);
    
    // systemInfo: 1.sys name | 2.sys number | 3. redu number | 4. data port | 5. event port | 6. dist port | 7. redundant sys ID | 8. parent sys ID
    fwInstallationDB_getPvssSystemProperties(sysName, systemInfo);
    
    fwConfigurationDBSystemInformation_getChildSystems(sysName, childSystems);
    
    dynClear(listOfChildren);
    
    for(j=1;j<=dynlen(childSystems);j++)
    {
     dynAppend(listOfChildren,childSystems[j][1]);
    }
    
    if(systemInfo[8]=="N/A" || systemInfo[8]=="")
       systemInfo[8]="0";
      
    string sysDp = "";
    
    fwSysOverview_getSystemDp(sysName, sysDp, exceptionInfo);
    if(dynlen(exceptionInfo)){//fwExceptionHandling_display(exceptionInfo); 
      continue;}
    
    dpCreate(sysDp, "FwSystemOverviewSystem");
    
    dpList[1] = sysDp + fwSysOverview_SYSTEM_NUMBER; 
    values[1]=systemInfo[FW_INSTALLATION_DB_SYSTEM_NUMBER];
    
    dpList[2] = sysDp + fwSysOverview_SYSTEM_DATA_PORT;
    values[2]=systemInfo[FW_INSTALLATION_DB_SYSTEM_DATA_PORT];
    
    dpList[3] = sysDp + fwSysOverview_SYSTEM_EV_PORT;
    values[3]=systemInfo[FW_INSTALLATION_DB_SYSTEM_EVENT_PORT];
    
    dpList[4] = sysDp + fwSysOverview_SYSTEM_DIST_PORT;
    values[4]=systemInfo[FW_INSTALLATION_DB_SYSTEM_DIST_PORT];
    
    dpList[5] = sysDp + fwSysOverview_SYSTEM_PARENT_ID;
    values[5]=systemInfo[FW_INSTALLATION_DB_SYSTEM_PARENT_SYS_ID];
    
    dpList[6] = sysDp + fwSysOverview_SYSTEM_HOSTNAME;
    values[6]=projectsInfo[1][FW_INSTALLATION_DB_PROJECT_HOST];
    
    dpList[7] = sysDp + fwSysOverview_SYSTEM_CHILDREN;
    values[7]=listOfChildren;
    
    dpList[8] = sysDp + fwSysOverview_SYSTEM_PROJECTS;
    values[8]=sysProjects;
    
    dpSet(dpList, values); 
   }
   
  if(fwSysOverview_checkDBConsistency() == false)
  {
    ChildPanelOnCentral("fwSystemOverview/fwSystemOverview_DB_Consistency.pnl", "DB Consistency", makeDynString());
  }

  return fwSysOverview_OK;
}


/** @deprecated 2018-06-26
  
*/
int fwSysOverview_resetPollingFlags()
{
  FWDEPRECATED();

  dyn_string dsDps;
  int i;
  
  dsDps=dpNames(getSystemName() + "*","FwSystemOverviewProject");
  
  if(dynlen(dsDps)>0)
  
  for(i = 1; i <= dynlen(dsDps); i++)
    {
       fwSysOverview_setIsPolling(dsDps[i], FALSE);
    }
}

/** @deprecated 2018-06-26
  
*/
int fwSysOverview_setProjPmonNotResponding(string projDp)
{
  FWDEPRECATED();

  return dpSet(projDp + fwSysOverview_STATE,fwSysOverview_PMON_NO_RESPONSE);
}


/** @deprecated 2018-06-26
  
*/
int fwSysOverview_updateAlarmConfiguration()
{ 
  FWDEPRECATED();

  dyn_string projectDps = dpNames("*", "FwSystemOverviewProject");
  dyn_string ex;
  for(int i = 1; i <= dynlen(projectDps); i++)
  {
    bool discrete = false;
    if(dpExists(projectDps[i] + ".readings.state:_alert_hdl.._discrete_states"))
      dpGet(projectDps[i] + ".readings.state:_alert_hdl.._discrete_states", discrete);  
    
    if(!discrete)
    {
      string project;
      string host, hostDp;
      fwSysOverview_getProjectDb(projectDps[i], project, ex);
      fwSysOverview_getProjectPc(projectDps[i], hostDp, ex);
      fwSysOverview_getHostDb(hostDp, host, ex);
      if(dynlen(ex)){fwExceptionHandling_display(ex);continue;}      
      DebugN("INFO: Updating alarm information for project: " + project + " in host: " + host);

      fwSysOverview_setProjectAlert(project, host, true, ex);
      if(dynlen(ex)){fwExceptionHandling_display(ex);continue;}      
      dyn_string managerDps = fwSysOverview_getProjectManagerDPs(projectDps[i]);
      for(int j = 1; j <= dynlen(managerDps); j++)
        fwSysOverview_setManagerAlert(managerDps[j], true, ex);
    }
  }
  
  if(dynlen(ex)) return -1;
  
  return 0;
}

/** @deprecated 2018-06-26
  
*/
int fwSysOverview_updateSysState(string sysDp)
{
  FWDEPRECATED();

  dyn_string projectDps;
  int projCStat, sysCStat;
  dyn_string exceptionInfo;

  fwSysOverview_getSystemProjects(sysDp,projectDps, exceptionInfo);

  for(int j = 1; j <= dynlen(projectDps); j++)
  {
    fwSysOverview_getDeviceState(projectDps[j], projCStat);
    if(j == 1)
      sysCStat = projCStat;
     
    else if(projCStat > sysCStat)
      sysCStat = projCStat;
  }
  
  return  dpSet(sysDp + fwSysOverview_STATE, sysCStat); 
}

/** @deprecated 2018-06-26
  
*/void fwSystemOverviewAlarmsMasking_executeFunction(string functionName, dyn_string arguments)
{
  FWDEPRECATED();

  if (isFunctionDefined(functionName) && (functionName != ""))
  {
     execScript("main(dyn_string arguments) {" + functionName + "(arguments);}", makeDynString(), arguments);
  }
}



/** @deprecated 2018-06-26
  
*/
bool fwSystemOverviewFunc_readConfigFile(string fileName)
{
  FWDEPRECATED();

  string       result;
  dyn_string   ds1;
  dyn_errClass err;

  dyn_string   sysDpList;
  int i = 0;
  DebugN("In fwSystemOverviewFunc_readConfigFile: " +fileName);
  if (!fileToString(fileName, result)){
    err = getLastError();
    if ( dynlen(err) && showErrorDialog ){
      errorDialog(err);
    }
    return(false);
  }

  strreplace(result, "\t", "");
  strreplace(result, "\r", "");
  while(strreplace(result, "\n\n", "\n") != 0);

  if(!fwSystemOverviewFunc_strTagSplit(result, "[system]", ds1)){
    if (showErrorDialog){
      popupMessage("_Ui_1", "in getConfig: Error: ABORTING: Check Log");
    }
    DebugN("in getConfig: Error: ABORTING: Check Log");

    return false;
  }
  
  if (!dpExists(fwSystemOverviewFunc_DPNAME_ARRAY)){
    dpCreate(fwSystemOverviewFunc_DPNAME_ARRAY , fwSystemOverviewFunc_SYSCOLL_TYPE);
    fwSystemOverviewFunc_setRefreshRate(4);
  }
  
  if(strlen(ds1[1]) > 0)
    DebugN("in readConfigFile: There should be no free text outside the [system] block: " + ds1[1]); 

  //remove first one as it is blank array because there should be no text outside the system block
  dynRemove(ds1, 1);
  
  if(!fwSystemOverviewFunc_readSysInfo(ds1, sysDpList)){
    if (showErrorDialog){
      popupMessage("_Ui_1", "in getConfig: Error: ABORTING: Check Log");
    }
    fwSystemOverviewFunc_deleteSysDP(sysDpList);
    DebugN("in getConfig: Error: ABORTING: Check Log");
    return false;
  }
  
  fwSystemOverviewFunc_setSysDPList(sysDpList);
  return true;
}


/** @deprecated 2018-06-26
  
*/int fwSystemOverviewFunc_connectPollProjectDpe()
{
  FWDEPRECATED();

  dyn_string sysDpList, projDpList;
  int i, j;
  
  fwSystemOverviewFunc_getSysDPList(sysDpList);
  
  for(i = 1; i <= dynlen(sysDpList); i++){
    fwSystemOverviewFunc_getProjDPList(sysDpList[i], projDpList);
  
    for(j = 1; j <= dynlen(projDpList); j++){
      dpConnect("fwSystemOverviewFunc_wfPollProject", FALSE, projDpList[j] + fwSystemOverviewFunc_POLL_PROJ_STR);
    }
  }
  return 0;   
}

/** @deprecated 2018-06-26
  
*/
int fwSystemOverviewFunc_disconnectPollProjectDpe()
{
  FWDEPRECATED();

  dyn_string sysDpList, projDpList;
  int i, j;
  dyn_errClass err;
  
  fwSystemOverviewFunc_getSysDPList(sysDpList);
  
  for(i = 1; i <= dynlen(sysDpList); i++){
    fwSystemOverviewFunc_getProjDPList(sysDpList[i], projDpList);
  
    for(j = 1; j <= dynlen(projDpList); j++){
//      err = dpDisconnect("fwSystemOverviewFunc_wfPollProject", projDpList[j] + fwSystemOverviewFunc_POLL_PROJ_STR);
      if(dpDisconnect("fwSystemOverviewFunc_wfPollProject", projDpList[j] + fwSystemOverviewFunc_POLL_PROJ_STR) == -1){
        err = getLastError();
        if ( dynlen(err)){
          DebugN(sysDpList[i], projDpList[j], projDpList[j] + fwSystemOverviewFunc_POLL_PROJ_STR, err);
        }
      }
    }
  }
  return 0;   
}


/** @deprecated 2018-06-26
  
*/
bool fwSystemOverviewFunc_deleteDPStruct()
{
  FWDEPRECATED();

  dyn_string dpNameList;
  
  fwSystemOverviewFunc_getSysDPList(dpNameList);
  
  for(int i = 1; i<= dynlen(dpNameList); i++)
    fwSystemOverviewFunc_deleteSysDP(dpNameList[i]);
  
  fwSystemOverviewFunc_deleteCollDP();
}






/** @deprecated 2018-06-26
  
*/

int fwSystemOverviewFunc_getProjData(string projDp, string& projName, int& projCStat, unsigned& sysNo, unsigned &pmonPortNo, unsigned &eventPortNo, 
                unsigned &dmPortNo, unsigned &distPortNo, string &sharedDir, string& hostIp, string& hostName)
{
  FWDEPRECATED();

  return dpGet(projDp + fwSystemOverviewFunc_PROJ_NAME_STR, projName, 
               projDp + fwSystemOverviewFunc_SYSNO_STR, sysNo, 
               projDp + fwSystemOverviewFunc_CURR_STATE_STR, projCStat,
               projDp + fwSystemOverviewFunc_PMON_PORT_STR, pmonPortNo, 
               projDp + fwSystemOverviewFunc_EVM_PORT_STR, eventPortNo,
               projDp + fwSystemOverviewFunc_DM_PORT_STR, dmPortNo,
               projDp + fwSystemOverviewFunc_DISTMAN_PORT_STR, distPortNo,
               projDp + fwSystemOverviewFunc_IP_STR, hostIp,
               projDp + fwSystemOverviewFunc_HOSTNAME_STR, hostName,
               projDp + fwSystemOverviewFunc_PROJ_PATH_STR, sharedDir);
}



/** @deprecated 2018-06-26
  
*/
bool fwSystemOverviewFunc_getRootNodes(dyn_string &rootDPs)
{  
  FWDEPRECATED();

  string dpArrayName = fwSystemOverviewFunc_DPNAME_ARRAY;
  dyn_string dpNameList, projDpList;
  dyn_uint childNodes;
  unsigned parentNode, sysNo;
  string sysName;
  
  
  fwSystemOverviewFunc_getSysDPList(dpNameList);

  for(int j = 1; j <= dynlen(dpNameList); j++){
    
    fwSystemOverviewFunc_getSysData(dpNameList[j], sysNo, sysName, parentNode, childNodes, projDpList);
        
    if(parentNode == 0 && dynContains(rootDPs, dpNameList[j]) == 0)
      dynAppend(rootDPs, dpNameList[j]);
  } 
  return(true);   
}




/** @deprecated 2018-06-26
  
*/
int fwSystemOverviewFunc_getStateFromStr(string stat)
{
  FWDEPRECATED();

  int str;
  
  switch(stat){
    case "STOPPED":
      str = fwSystemOverviewFunc_STOPPED_NORMAL;
      break;
    case "INITIALIZE":
      str = fwSystemOverviewFunc_INITIALIZE;
      break;
    case "RUNNING":
      str = fwSystemOverviewFunc_RUNNING;
      break;
    case "BLOCKED":
      str = fwSystemOverviewFunc_BLOCKED;
      break;
    case "STOPPED ABNORMAL":
      str = fwSystemOverviewFunc_STOPPED_ABNORMAL;
      break;
    case "RAPID RESTART":
      str = fwSystemOverviewFunc_RAPID_RESTART;
      break;
    case "PROJECT NAME MISMATCH":
      str = fwSystemOverviewFunc_PROJNAME_MISMATCH;
      break;
    case "PMON NOT RESPONDING":
      str = fwSystemOverviewFunc_PMON_NO_RESPONSE;
      break;
    case "PMON NOT RUNNING":
      str = fwSystemOverviewFunc_PMON_NOT_RUNNING;
      break;
    default:
      str = -1;
      break;
   }
  
  return str;
}





/** @deprecated 2018-06-26
  
*/
int fwSystemOverviewFunc_getSysState(string sysDp, unsigned& sysState)
{
  FWDEPRECATED();

  return dpGet(sysDp + fwSystemOverviewFunc_CURR_STATE_STR, sysState);
}


/** @deprecated 2018-06-26
  
*/
  
int fwSystemOverviewFunc_pollSystems()
{
  FWDEPRECATED();

  dyn_string sysDpList, projDpList, dpeList;
  dyn_bool valueList;
  
  int i, j;
  
//  DebugN("In fwSystemOverviewFunc_pollSystems: Called");
  
  fwSystemOverviewFunc_getSysDPList(sysDpList);
  
  for(i = 1; i <= dynlen(sysDpList); i++){
    fwSystemOverviewFunc_getProjDPList(sysDpList[i], projDpList);
    
    for(j = 1; j <= dynlen(projDpList); j++){
      dynAppend(dpeList, projDpList[j] + fwSystemOverviewFunc_POLL_PROJ_STR);
      dynAppend(valueList, TRUE);
    }
//      fwSystemOverviewFunc_pollProject(projDpList[j]);
  }
  
  dpSet(dpeList, valueList);

  for(i = 1; i <= dynlen(sysDpList); i++){
    fwSystemOverviewFunc_updateSysState(sysDpList[i]);
  }
  return 0;   
}



/** @deprecated 2018-06-26
  
*/

void fwSystemOverviewFunc_populateFilterListFromDp(dyn_uint& sysNoList, dyn_string& sysNameList, dyn_string& hostList, dyn_int& stateList, dyn_string& managerNameList)
{
  FWDEPRECATED();

  dyn_string sysDpList;
  dyn_string projDpList;
  string sysName, hostName, userName, userPassword, sharedDir, type;
  unsigned sysNo, parentNo, pmonPortNo;
  dyn_uint childNodes;
      
//  dyn_int 
  
  fwSystemOverviewFunc_getSysDPList(sysDpList);

  //get manager types from the datapoint, to modify if want to reduce the manager types
  for(int i = 1; i <= dynlen(sysDpList); i++){
    fwSystemOverviewFunc_getSysData(sysDpList[i], sysNo, sysName, parentNo, childNodes, projDpList);
    dynAppend(sysNoList, sysNo);
    
    for(int j = 1; j <= dynlen(projDpList); j++){
      fwSystemOverviewFunc_getProjAccessData(projDpList[j], hostName, pmonPortNo, userName, userPassword, sharedDir);
      dynAppend(hostList, hostName);
      fwSystemOverviewFunc_getProjManagersType(projDpList[j], type);
      dynAppend(managerNameList, type);
    }
  }
  
  dynUnique(sysNoList);
  dynSortAsc(sysNoList);
  
  dynClear(sysNameList);
  
  for(int i = 1; i <= dynlen(sysNoList); i++){
    fwSystemOverviewFunc_getSysName(fwSystemOverviewFunc_sysNoToDp(sysNoList[i]), sysName);
    dynAppend(sysNameList, sysName);
  }
  
  dynUnique(hostList);
  dynSortAsc(hostList);
  
  fwSystemOverviewFunc_getStateList(stateList);
  dynUnique(stateList);
  dynSortAsc(stateList);
  
  dynUnique(managerNameList);
  dynSortAsc(managerNameList);
}




/** @deprecated 2018-06-26
  
*/
fwSystemOverviewFunc_resetPollingFlags()
{
  FWDEPRECATED();

  dyn_string sysDpList, projDpList;
  int i, j;
  
  fwSystemOverviewFunc_getSysDPList(sysDpList);
  
  for(i = 1; i <= dynlen(sysDpList); i++){
    fwSystemOverviewFunc_getProjDPList(sysDpList[i], projDpList);
    for(j = 1; j <= dynlen(projDpList); j++){
      fwSystemOverviewFunc_setIsPolling(projDpList[j], FALSE);
    }
  }
}


/** @deprecated 2018-06-26
  
*/

int fwSystemOverviewFunc_setProjDPList(string sysDp, dyn_string projDpList)
{
   FWDEPRECATED();

 return dpSet(sysDp + fwSystemOverviewFunc_PROJLIST_STR, projDpList);
}

/** @deprecated 2018-06-26
  
*/

int fwSystemOverviewFunc_sysDpToNo(string sysDp)
{
  FWDEPRECATED();

  strreplace(sysDp, fwSystemOverviewFunc_SYSVIEW_NODE, "");
  return (int)sysDp;
}

/** @deprecated 2018-06-26
  
*/
int fwSystemOverviewFunc_getIsPolling(string projDp, bool& isPolling)
{
  FWDEPRECATED();

  return dpGet(projDp + fwSystemOverviewFunc_IS_POLL_PROJ_STR, isPolling);
}

/** @deprecated 2018-06-26
  
*/

int fwSystemOverviewFunc_setIsPolling(string projDp, bool isPolling)
{
  FWDEPRECATED();

  return dpSet(projDp + fwSystemOverviewFunc_IS_POLL_PROJ_STR, isPolling);
}


/** @deprecated 2018-06-26
  
*/
void fwSysOverviewNotifications_clearInhibitPatterns(string application, time olderThanDate)
{
  FWDEPRECATED();

   string dp = fwSysOverviewNotifications_getDp(application);   
   dyn_string currentInhibitPatterns, newInhibitPatterns, currentInhibitTimes, newInhibitTimes;
   dpGet(dp + ".inhibitPatterns", currentInhibitPatterns,
         dp + ".inhibitUntil", currentInhibitTimes);
   for(int i=1; i<=dynlen(currentInhibitPatterns); i++)
   {
     time t = (time)currentInhibitTimes[i];
     if (t > olderThanDate)
     {
       dynAppend(newInhibitPatterns, currentInhibitPatterns[i]);
       dynAppend(newInhibitTimes, currentInhibitTimes[i]);
     }
   }
   
   string inhibitStr = newInhibitPatterns;
   strreplace(inhibitStr, " | ", ";");
   string inhibitUntilStr = newInhibitTimes;
   strreplace(inhibitUntilStr, " | ", ";");
   dpSet(dp + ".inhibitPatterns", inhibitStr,
         dp + ".inhibitUntil", inhibitUntilStr);
  
}


/** @deprecated 2018-06-26
  
*/
string _fwSysOverviewNotifications_convertSecondsToMinutesString(int seconds)
{
  FWDEPRECATED();

  int m = seconds/60;
  
  return (string)m + " minutes";
}

/** @deprecated 2018-06-26
  
*/
void fwSysOverviewNotifications_enable(string application)
{
  FWDEPRECATED();

   string dp = fwSysOverviewNotifications_getDp(application);    
   if (dpExists(dp))
   {
     dpSet(dp+ ".active", true);
   }
}
/** @deprecated 2018-06-26
  
*/
void fwSysOverviewNotifications_disable(string application)
{
  FWDEPRECATED();

   string dp = fwSysOverviewNotifications_getDp(application);    
   if (dpExists(dp))
   {
     dpSet(dp+ ".active", false);
   }
}
/** @deprecated 2018-06-26
  
*/
void fwSysOverviewNotifications_inhibitAllAlarms(string cunit, dyn_string alarms,string inhibitUntil)
{
  FWDEPRECATED();

  if (dynlen(alarms) >0)
  {
    string application;
    fwSysOverviewNotifications_getApplication(alarms[1], application);
    string dp = fwSysOverviewNotifications_getDp(application);
    
    if(dpExists(dp))
    {
      dyn_string inhibitUntilArr;
      for(int i=1; i<=dynlen(alarms); i++)
        dynAppend(inhibitUntilArr, inhibitUntil);
      string inhibitStr = alarms;
      strreplace(inhibitStr, " | ", ";");
      string inhibitUntilStr = inhibitUntilArr;
      strreplace(inhibitUntilStr, " | ", ";");
      dpSet(dp + ".inhibitPatterns", inhibitStr,
            dp + ".inhibitUntil", inhibitUntilStr);
    }
  }
}



/** @deprecated 2018-06-26
  
*/
int fwSysOverviewUi_connectDp2Ui(string workFuncSys, bool firstUpdate = TRUE)
{
  FWDEPRECATED();

  dyn_string systemDpNames;
  int i;
  
  fwSysOverview_getSystemsDps(systemDpNames);
  
  for(i = 1; i <= dynlen(systemDpNames); i++){
    dpConnect(workFuncSys, firstUpdate, systemDpNames[i] + fwSysOverview_STATE);
  }
  return fwSysOverview_OK;   
}

/** @deprecated 2018-06-26
  
*/
int fwSysOverviewUi_disconnectDp2Ui(string workFuncSys)
{
  FWDEPRECATED();

  dyn_string systemDpNames;
  int i, j;
  
   fwSysOverview_getSystemsDps(systemDpNames);
  
  for(i = 1; i <= dynlen(systemDpNames); i++){
    dpDisconnect(workFuncSys, systemDpNames[i] + fwSysOverview_STATE);
  }
  return fwSysOverview_OK;   
}


/** @deprecated 2018-06-26
  
*/
void fwSysOverviewUi_populateFilterListFromDp(dyn_string& sysNameList, dyn_string& hostList, dyn_int& stateList, dyn_string& managerNameList)
{
  FWDEPRECATED();

  dyn_string systemDpNames;
  string sysName;
  unsigned sysNo, parentNo, pmonPortNo;
  dyn_uint childNodes;
      
  dynClear(sysNameList);
  
  fwSysOverview_getSystemsDps(systemDpNames);
  if(dynlen(systemDpNames) <= 0)
  {
    DebugN("WARNING: Application not yet configured. No system found");
    return;
  }


  for(int i = 1; i <= dynlen(systemDpNames); i++){
    fwSysOverview_getDeviceName(systemDpNames[i], sysName);
    dynAppend(sysNameList, sysName);
  }
 
  fwSysOverview_getHosts(hostList);

}




/** @deprecated 2018-06-26
  
*/

bool fwSysOverviewUi_populateFilterTable(shape filterTable, dyn_string itemList)
{
  FWDEPRECATED();

  filterTable.deleteAllLines();
 
  filterTable.tableMode(TABLE_SELECT_MULTIPLE);
  filterTable.selectByClick(TABLE_SELECT_LINE);
  dynInsertAt(itemList, "All", 1);
  
  filterTable.appendLines(dynlen(itemList), filterTable.columnToName(0),itemList);
  filterTable.selectLineN(0);
  filterTable.lineVisible(0);
}


/** @deprecated 2018-06-26
  
*/

bool fwSysOverviewUi_toggleTreeViewMode(shape tree, string command)
{  
  FWDEPRECATED();

  dyn_string rootNodeList;
  
  if(tree.itemExists(fwSysOverviewUi_gInstanceName)){
    rootNodeList = tree.children(fwSysOverviewUi_gInstanceName);
    for(int i = dynlen(rootNodeList); i >= 1; i--){
      tree.setVisible(rootNodeList[i], 
                                      fwSysOverviewUi_setVisibleTreeNodes(tree, rootNodeList[i], command, fwSysOverviewUi_gSysNoFltLst, 
                                                          fwSysOverviewUi_gHostNameFltLst, fwSysOverviewUi_gManNameFltLst, 
                                                          fwSysOverviewUi_gManStateFltLst));
    }
    tree.ensureItemVisible(fwSysOverviewUi_gInstanceName);
    fwSysOverviewUi_hideColumns(tree, fwSysOverviewUi_gTreeViewMode);
  }
  return true;
} 

/** @deprecated 2018-06-26
  
*/
int fwSysOverviewUi_populateMappingSysView(shape tree)
{
  FWDEPRECATED();

  dyn_string rootDPs;
  
  fwSysOverview_getRootNodes(rootDPs);
    
  if(!tree.itemExists(fwSysOverviewUi_gInstanceName))
    tree.appendItem("", fwSysOverviewUi_gInstanceName, fwSysOverviewUi_gInstanceName);
  
  for(int rootindex = 1; rootindex <= dynlen(rootDPs); rootindex++)
    fwSysOverviewUi_populateSysTree(tree, rootDPs[rootindex], fwSysOverviewUi_gInstanceName,FALSE);

  tree.setOpen(fwSysOverviewUi_gInstanceName ,true);
  
}



/** @deprecated 2018-06-26
  
*/
void fwSysOverviewUi_refreshFsmView(shape tree)
{
  FWDEPRECATED();

  dyn_string treeNodeList = tree.children(fwSysOverviewUi_gInstanceName);
  int childno = dynlen(treeNodeList);
  
  for(int i = 1; i <= childno; i++){
    fwSysOverviewUi_refreshFsmState(tree, treeNodeList[i]);
  }
}

/** @deprecated 2018-07-24  
*/
void fwSysOverview_getApplicationSystems(string application, dyn_string &systems, dyn_int &ids)
{
  FWDEPRECATED();

  dyn_dyn_string dps = fwSysOverviewFsm_getChildrenOfTypeWithDomain(application, "FwSystemOverviewProject", application);   
  for(int i = 1; i <= dynlen(dps); i++)
  {
    string sysDp = "", sys = "";
    int id = -1;
    dyn_string ex;
    fwSysOverview_getProjectSystem(dps[i][1], sysDp, ex);
    fwSysOverview_getSystemDb(sysDp, sys, ex);
    if(dynlen(ex))
      DebugN(ex, dps[i][1], sysDp, sys);
    
    if(dynContains(systems, sys)> 0) //system already found. Skip!
      continue;
    
    dynAppend(systems, sys);
    dpGet(sysDp + ".config.sysNumber", id);
    dynAppend(ids, id);
  }
  return;
}


/** @deprecated 2018-06-26
  
*/
void fwSysOverviewUi_updateSysStateInTree(shape tree, string sysDp)
{
  FWDEPRECATED();

  int sysState;
  dyn_string projDpList;
  
  fwSysOverview_getDeviceState(sysDp, sysState);
  
  tree.setIcon(sysDp, 1, fwSysOverviewUi_getIconState(sysState));
  tree.setText(sysDp, 1, fwSysOverview_getStrFromState(sysState));
}


/** @deprecated 2018-07-24  
*/
mapping fwSysOverview_getAlarmCategories()
{
  FWDEPRECATED();
  
  mapping m;
  
//  m["Al Arch"] = "*_archive_Alarm_*";  
  m["Hosts"] = "*:FMC/*;*:_ArchiveDisk.FreeKB;*:_MemoryCheck.FreeKB";  
  m["Projects"] = "*:SystemOverview/*;*_backup_check_*";  
  m["RDB"] = "*_RDB_RDBArchive_*";  
  m["Logging DB"] = "*_LHCLoggingDB_*";  
  m["PVSS DB"] = "*_PVSSDB_*";  
  m["Dist"] = "*_unDistributedControl_*";  
  m["PLCs"] = "*-IcemonPlc-*.ProcessInput.metric*;*_PLC_DS_Error_*;*_import_S7_PLC_*";  
  m["FE Comm"] = "*_DS_Comm_*;*_DS_Time_*";  
  m["DIP"] = "*_DPE_dip/*";  
  m["CMW"] = "*_CMWServer_*;*_CMWClient_*";  
  m["Laser"] = "*_Laser_*";  
//  m["Val Arch"] = "*_ValueArchive_*";  
  
  return m;
}



/** @deprecated 2018-07-24  
*/
void fwSysOverview_createSystem(dyn_mixed projectInfo, dyn_string &exceptionInfo)
{
  FWDEPRECATED();
  
  string systemName = projectInfo[fwSysOverview_PROJECT_SYSTEM_NAME_IDX];
  string systemNum = projectInfo[fwSysOverview_PROJECT_SYSTEM_NUM_IDX];
  string hostName = projectInfo[fwSysOverview_PROJECT_HOST_IDX];
  bool exists = false;
  string archiveClass = "";
  int enable;

  string sysDp = "";
  fwSysOverview_getSystemDp(systemName, hostName, sysDp, exceptionInfo);
  if(dynlen(exceptionInfo))
    return;
      
  fwSysOverview_systemExists(systemName, exists, hostName, exceptionInfo); 
  if(dynlen(exceptionInfo)){return;}
  
  if(!exists)
  {  
    dpCreate(sysDp, "FwSystemOverviewSystem");
    
    fwSysOverview_isArchivingEnabled(enable);
    if(enable !=0)
    {
      fwSysOverview_getAchiveClass(archiveClass);
      if(archiveClass != "")
      {
        fwSysOverview_createArchiveConfig(sysDp + fwSysOverview_STATE, archiveClass, exceptionInfo);
        if(dynlen(exceptionInfo)){return;}
      }
    }    
  }
    

  dpSetWait(sysDp + fwSysOverview_SYSTEM_NAME, systemName,
            sysDp + fwSysOverview_SYSTEM_NUMBER, systemNum);
  return;
}



/** @deprecated 2018-07-24  
*/
int fwSysOverview_checkSystemSubdetector(string systemName)
{
  FWDEPRECATED();

  if(strpos(getSystemName(), "ATLGCSSYS") < 0) 
  {
    string subdetId = strtoupper(fwAtlas_getSubdetectorId(getSystemName()));
  	 string str = substr(systemName, 3, 3);
  	 if(subdetId != str)
    {
      DebugTN("Ignoring PVSS system " + systemName + " since it is not part of subdetector " + subdetId);
      return -1;
     }
  }
  else
    return -1;
}




